
  var svg = d3.select('svg');

//color scale for the legend
var colorScale = d3.scaleOrdinal()
  .domain(['5_5.9', '6_6.9', '7_7.9', '8.0+'])
  .range(['#FFC300', '#FF5733', '#C70039', '#900C3F']);


//setting width and height
var width = +svg.attr('width');
var height = +svg.attr('height');

//rendering data
var render = data => {
  var xValue=  d => d.year; 
  var yValue_5_9 =  d => d["5_5.9"];
  var yValue_6_9 =  d => d["6_6.9"];
  var yValue_7_9 =  d => d["7_7.9"];
  var yValue_8_0 =  d => d["8.0+"]; 


  //setting axis lables, title and margins
  var xAxisLabel = 'Year';
  var yAxisLabel = 'Num of Earthquakes';
	var title = 'Worldwide Earthquake stats 2000-2015 log scale';
  var margin = { top: 50, right: 125, bottom: 80, left: 100};
  var innerWidth = width - margin.left - margin.right;
  var innerHeight = height - margin.top - margin.bottom;

  //setting the scale of the x axis
  var xScale = d3.scaleTime()
  	.domain([d3.min(data, xValue), d3.max(data, xValue)])
  	.range([0, innerWidth]);
   
   //setting the scale of the y axis
  var yScale = d3.scaleLog()
    .clamp(true)
  	.domain([1, d3.max(data, yValue_5_9)])
  	.range([innerHeight, 0])
   
  
  var g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  	
  
  var xAxis = d3.axisBottom(xScale)
  var yAxis = d3.axisLeft(yScale)

    
  var yAxisG = g.append('g').call(yAxis);

  
  yAxisG.append('text')
  	.attr('class', 'xAxisLabel')
  	.text(yAxisLabel)
  	.attr('y', -70)
  	.attr('x', -innerHeight/2)
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle');
  
  //creating the x axis
  var xAxisG = g.append('g')
  	.call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.append('text')
  	.attr('class', 'xAxisLabel')
  	.text(xAxisLabel)
  	.attr('fill', 'black')
  	.attr('y', 50)
  	.attr('x', innerWidth/2);
 
  
  var line_5_9 = d3.line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue_5_9(d)))
  	.curve(d3.curveMonotoneX);
  
  var line_6_9 = d3.line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue_6_9(d)))
  	.curve(d3.curveMonotoneX);
  
  var line_7_9 = d3.line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue_7_9(d)))
  	.curve(d3.curveMonotoneX);
  
  var line_8_0 = d3.line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue_8_0(d)))
  	.curve(d3.curveMonotoneX);
  
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#FFC300")
    .attr('d', line_5_9(data));
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#FF5733")
    .attr('d', line_6_9(data));
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#C70039")
    .attr('d', line_7_9(data));
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#900C3F")
    .attr('d', line_8_0(data));
  
  g.append('text')
    .attr('class', 'title')
  	.text(title)
  	.attr('x', width/12)
  	.attr('y', -20);
  
  //adding data points
  var datapoints = g.append('g')
  	.attr('class', 'line-and-dots')
  	.attr('tranform', 'translate(' + ((margin.left + margin.right) /2) + ',' + 0 + ')')
  
  //scaling function for data points
  var rScale5 = d3.scaleLinear()
  		.domain([231, 298101])
  		.range([5, 15])
  //	
  
  //datapoints for 5.9
  datapoints.selectAll('line-circle')
  	.data(data)
  	.enter().append('circle')
  	.attr('class', 'data-circle')
  	.attr('cx', function(d) { return xScale(d.year); })
  	.attr('cy', function(d) { return yScale(d['5_5.9']); })
 	  .attr('r', function(d) { return rScale5(d['Estimated Deaths']) })
  	.style('fill', '#FFC300');
  

	  //datapoints for 6.9
  datapoints.selectAll('line-circle')
  	.data(data)
  	.enter().append('circle')
  	.attr('class', 'data-circle')
  	.attr('r', function(d) { return rScale5(d['Estimated Deaths']) })
  	.attr('cx', function(d) { return xScale(d.year); })
  	.attr('cy', function(d) { return yScale(d['6_6.9']); })
  	.style('fill', '#FF5733');
  
  	  //datapoints for 7.9
  datapoints.selectAll('line-circle')
  	.data(data)
  	.enter().append('circle')
  	.attr('class', 'data-circle')
  	.attr('r', function(d) { return rScale5(d['Estimated Deaths']) })
  	.attr('cx', function(d) { return xScale(d.year); })
  	.attr('cy', function(d) { return yScale(d['7_7.9']); })
  	.style('fill', '#C70039');
  
  
    //datapoints for 8+
  datapoints.selectAll('line-circle')
  	.data(data)
  	.enter().append('circle')
  	.attr('class', 'data-circle')
  	.attr('r', function(d) { return rScale5(d['Estimated Deaths']) })
  	.attr('cx', function(d) { return xScale(d.year); })
  	.attr('cy', function(d) { return yScale(d['8.0+']); })
  	.style('fill', '#900C3F');
  
  
  //creating a legend
  var colorLegend = (selection, props) => {
  var { colorScale} = props;
  
  var groups = selection.selectAll('g')
    .data(colorScale.domain());
  
  var groupsEnter = groups.enter().append('g');
  
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) =>
        `translate(0, ${i * 30})`
      );
  groups.exit().remove();
  
  //creating the squares for the legend
  groupsEnter.append('rect')
    .merge(groups.select('rect'))
  		.attr('y', -10)  //positioning the squares to be lined up with the text
  		.attr('height', 10)
  		.attr('width', 10)
      .attr('fill', colorScale);
  
  //adding the text
  groupsEnter.append('text')
  	.merge(groups.select('text'))
  		.text(d => d)
  		.attr('x', 20);  //changes the spacing between text and squares
}
  
  
  //adding the legend
  svg.append('g')
  	.attr('transform', `translate(860, 70)`)
  	.call(colorLegend, {
    	colorScale,
    	circleRadius: 30
  });  	
};


d3.csv('https://vizhub.com/Mike191/datasets/earthquakes.csv')
  .then(data => {
  	data.forEach(d => {
      console.log(d)
      d.year = new Date(d.year,0,1);
      d["8.0+"] = +d["8.0+"];
      d["7_7.9"] = +d["7_7.9"];
      d["6_6.9"] = +d["6_6.9"];
      d["5_5.9"] = +d["5_5.9"];

    });
  	render(data);
  });




